/*

*/

import java.awt.*;
import javax.swing.*;

/**
   This program draws a fan of lines two times, once using
   Java's default lines, and a second time using Java's
   antialiased lines. The two fans are displayed side-by-side.

   To see how the antialiasing works, look at the final rendered
   image using a pixel magnifying program.
*/
public class AntialiasingDemo_JavaAPI extends JPanel
{
   private final int SIZE = 900;
   private final int NUMBER_OF_LINES = 30;

   public AntialiasingDemo_JavaAPI()
   {
      Dimension dim = new Dimension(2*SIZE, SIZE);
      setPreferredSize(dim);
   }

   @Override
   public void paintComponent(Graphics g)
   {
      super.paintComponent(g);
      // recover Graphics2D
      Graphics2D g2 = (Graphics2D)g;

      g2.setColor(Color.black);
      g2.fillRect(0, 0, 2*SIZE + 1, SIZE + 1);
      g2.setColor(Color.white);

      // draw the left half of the screen using Java's anti-aliased lines
      g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
      for (int i = 0; i <= NUMBER_OF_LINES; i++)
      {
         g2.drawLine(0, SIZE, SIZE, SIZE - (int)(i * ((double)SIZE/(double)NUMBER_OF_LINES)) );
         g2.drawLine(0, SIZE, (int)(i * ((double)SIZE/(double)NUMBER_OF_LINES)), 0 );
      }

      // draw the right half of the screen using Java's default lines
      g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_OFF);
      for (int i = 0; i <= NUMBER_OF_LINES; i++)
      {
         g2.drawLine(SIZE, SIZE, 2*SIZE, SIZE - (int)(i * ((double)SIZE/(double)NUMBER_OF_LINES)) );
         g2.drawLine(SIZE, SIZE, SIZE + (int)(i * ((double)SIZE/(double)NUMBER_OF_LINES)), 0 );
      }
   }


   public static void main(String[] args)
   {
      javax.swing.SwingUtilities.invokeLater(() ->
      {
         JFrame f = new JFrame();
         f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
         f.setTitle("Renderer_4");
         f.setResizable(false);
         f.add(new AntialiasingDemo_JavaAPI(), BorderLayout.CENTER);
         f.pack();
         f.setLocationRelativeTo(null);
         f.setVisible(true);
      });
   }
}
